@@ -1,6 +1,6 @@
 /* pathnames.h -- absolute filenames that bash wants for various defaults. */
 
-/* Copyright (C) 1987-2009 Free Software Foundation, Inc.
+/* Copyright (C) 1987-2009,2024 Free Software Foundation, Inc.
 
    This file is part of GNU Bash, the Bourne Again SHell.
 
@@ -28,6 +28,6 @@
 #define SYS_PROFILE "/etc/profile"
 
 /* The default location of the bash debugger initialization/startup file. */
-#define DEBUGGER_START_FILE	"/usr/pkg/share/bashdb/bashdb-main.inc"
+#define DEBUGGER_START_FILE	"/usr/local/share/bashdb/bashdb-main.inc"
 
 #endif /* _PATHNAMES_H */
